==> haskell-floskell-0.10.8-179.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-floskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 floskell
version:              0.10.8
visibility:           public
id:                   floskell-0.10.8-AxOvA0LXC8d9OWxkw4MIsF
key:                  floskell-0.10.8-AxOvA0LXC8d9OWxkw4MIsF
license:              BSD-3-Clause
copyright:
    2014 Chris Done, 2015 Andrew Gibiansky, 2016-2023 Enno Cramer

maintainer:           ecramer@memfrob.de
author:
    Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker, Enno Cramer

stability:            Unstable
homepage:             https://github.com/ennocramer/floskell
synopsis:             A flexible Haskell source code pretty printer
description:
    A flexible Haskell source code pretty printer.

    See the Github page for usage\/explanation: <https://github.com/ennocramer/floskell>

category:             Development
abi:                  32289dfe1e47e84ca4911672ed5308c5
exposed:              True
exposed-modules:
    Floskell Floskell.Attoparsec Floskell.Buffer Floskell.Comments
    Floskell.Config Floskell.ConfigFile Floskell.Fixities
    Floskell.Imports Floskell.Pretty Floskell.Printers Floskell.Styles
    Floskell.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/floskell-0.10.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/floskell-0.10.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/floskell-0.10.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-floskell
hs-libraries:         HSfloskell-0.10.8-AxOvA0LXC8d9OWxkw4MIsF
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    filepath-1.4.300.1 haskell-src-exts-1.23.1-F3jL8MeOgpf1H3BDGTEVcV
    monad-dijkstra-0.1.1.5-gta9FhokqxBKrZs41z2vf mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y

haddock-interfaces:   /usr/share/doc/haskell-floskell/html/floskell.haddock
haddock-html:         /usr/share/doc/haskell-floskell/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-floskell-0.10.8-180-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-floskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 floskell
version:              0.10.8
visibility:           public
id:                   floskell-0.10.8-A4Jk62LRm65KpwXvndUnOp
key:                  floskell-0.10.8-A4Jk62LRm65KpwXvndUnOp
license:              BSD-3-Clause
copyright:
    2014 Chris Done, 2015 Andrew Gibiansky, 2016-2023 Enno Cramer

maintainer:           ecramer@memfrob.de
author:
    Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker, Enno Cramer

stability:            Unstable
homepage:             https://github.com/ennocramer/floskell
synopsis:             A flexible Haskell source code pretty printer
description:
    A flexible Haskell source code pretty printer.

    See the Github page for usage\/explanation: <https://github.com/ennocramer/floskell>

category:             Development
abi:                  8300cb1762a66a43e47aec7c06308b8b
exposed:              True
exposed-modules:
    Floskell Floskell.Attoparsec Floskell.Buffer Floskell.Comments
    Floskell.Config Floskell.ConfigFile Floskell.Fixities
    Floskell.Imports Floskell.Pretty Floskell.Printers Floskell.Styles
    Floskell.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/floskell-0.10.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/floskell-0.10.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/floskell-0.10.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-floskell
hs-libraries:         HSfloskell-0.10.8-A4Jk62LRm65KpwXvndUnOp
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    filepath-1.4.300.1 haskell-src-exts-1.23.1-63590nDmfj1880iQCS4JdS
    monad-dijkstra-0.1.1.5-J0E2HYyIDK76oipfKwBO1x mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:   /usr/share/doc/haskell-floskell/html/floskell.haddock
haddock-html:         /usr/share/doc/haskell-floskell/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
